@@ -1,5 +1,6 @@
 extern crate pointprocesses;
 extern crate gnuplot;
+extern crate serde_json;
 
 use gnuplot::{Figure,Caption,Color,PointSymbol,PointSize};
 
@@ -7,7 +8,6 @@ use pointprocesses::event::Event;
 use pointprocesses::poisson_process;
 
 
-
 fn main() {
     
     let tmax = 10.0;
@@ -15,7 +15,9 @@ fn main() {
 
     let events: Vec<Event> = poisson_process(tmax, lambda);
 
-    println!("{:?}", events);
+    println!("{}",
+        serde_json::to_string_pretty(&events).unwrap()
+    );
     
 
     let mut event_times: Vec<f64> = vec!();
@@ -27,7 +29,7 @@ fn main() {
     }
 
     let mut fg = Figure::new();
-    fg.set_terminal("wxt", "");
+    
     fg.axes2d()
         .points(&event_times, &event_intens, 
             &[
